import { Connection } from "../connection/Connection";
import { QueryRunner } from "../query-runner/QueryRunner";
import { SubjectCollection } from "./subject/SubjectCollection";
/**
 * Executes PersistOperation in the given connection.
 */
export declare class PersistSubjectExecutor {
    private connection;
    private queryRunner;
    constructor(connection: Connection, queryRunner: QueryRunner);
    /**
     * Executes given persist operation.
     */
    execute(subjects: SubjectCollection): Promise<void>;
    /**
     * Executes insert operations.
     */
    private executeInsertOperations(insertSubjects);
    /**
     * Executes insert operations for closure tables.
     */
    private executeInsertClosureTableOperations(insertSubjects);
    /**
     * Executes insert junction operations.
     */
    private executeInsertJunctionsOperations(subjects, insertSubjects);
    /**
     * Executes remove junction operations.
     */
    private executeRemoveJunctionsOperations(subjects);
    /**
     * Executes update relations operations.
     */
    private executeUnsetRelationOperations(subjects);
    private unsetRelations(subject);
    private executeSetRelationOperations(subjects);
    private setRelations(subject);
    /**
     * Executes update operations.
     */
    private executeUpdateOperations(updateSubjects);
    /**
     * Executes remove operations.
     */
    private executeRemoveOperations(removeSubjects);
    /**
     * Updates all special columns of the saving entities (create date, update date, versioning).
     */
    private updateSpecialColumnsInPersistedEntities(insertSubjects, updateSubjects, removeSubjects);
    private update(subject);
    private remove(subject);
    /**
     * Inserts an entity from the given insert operation into the database.
     * If entity has an generated column, then after saving new generated value will be stored to the InsertOperation.
     * If entity uses class-table-inheritance, then multiple inserts may by performed to save all entities.
     */
    private insert(subject, alreadyInsertedSubjects);
    private collectColumnsAndValues(metadata, entity, date, parentIdColumnValue, discriminatorValue, alreadyInsertedSubjects);
    private insertClosureTableValues(subject, insertedSubjects);
    private insertJunctions(subject, junctionInsert, insertSubjects);
    private removeJunctions(subject, junctionRemove);
    private zipObject(keys, values);
}
